@@ -226,9 +226,19 @@ class PlominoDocument(CatalogAware, CMFBTreeFolder, Contained):
 
     security.declarePublic('tojson')
     def tojson(self, REQUEST=None, item=None, formid=None, rendered=False):
-        """return item value as JSON
-        (return all items if item=None)
+        """ Return item value as JSON.
+
+        Return all items if `item=None`.
+        Values on the REQUEST overrides parameters.
+
+        If the requested item corresponds to a field on the found form, 
+        the field value is returned. If not, it falls back to a plain item
+        lookup on the document.
+
+        `formid="None"` specifies plain item lookup.
         """
+        # TODO: Don't always return the entire dataset.
+
         if not self.isReader():
             raise Unauthorized, "You cannot read this content"
 
@@ -243,32 +253,38 @@ class PlominoDocument(CatalogAware, CMFBTreeFolder, Contained):
             datatables_format_str = REQUEST.get('datatables', None)
             if datatables_format_str:
                 datatables_format = True
-        if not item:
-            return json.dumps(self.items.data)
-
-        if not formid:
-            form = self.getForm()
-        else:
-            form = self.getParentDatabase().getForm(formid)
-        if form:
-            field = form.getFormField(item)
-            if field:
-                if field.getFieldType() == 'DATAGRID':
-                    adapt = field.getSettings()
-                    fieldvalue = adapt.getFieldValue(form, self, False, False, REQUEST)
-                    fieldvalue = adapt.rows(fieldvalue, rendered=rendered)
-                    if datatables_format:
-                        fieldvalue = { 'iTotalRecords': len(fieldvalue), 'aaData': fieldvalue }
-                else:
-                    if rendered:
-                        fieldvalue = self.getRenderedItem(item, form)
-                    else:
+        if item:
+            if formid == "None":
+                form = None
+            elif formid:
+                form = self.getParentDatabase().getForm(formid)
+            else:
+                form = self.getForm()
+            if form:
+                field = form.getFormField(item)
+                if field:
+                    if field.getFieldType() == 'DATAGRID':
                         adapt = field.getSettings()
                         fieldvalue = adapt.getFieldValue(form, self, False, False, REQUEST)
+                        fieldvalue = adapt.rows(fieldvalue, rendered=rendered)
+                    else:
+                        if rendered:
+                            fieldvalue = self.getRenderedItem(item, form)
+                        else:
+                            adapt = field.getSettings()
+                            fieldvalue = adapt.getFieldValue(form, self, False, False, REQUEST)
+                else:
+                    logger.info("Failed to find %s on %s, fallback to getItem."%(item, form.id))
+                    fieldvalue = self.getItem(item)
             else:
                 fieldvalue = self.getItem(item)
         else:
-            fieldvalue = self.getItem(item)
+            fieldvalue = self.items.data
+
+        if datatables_format:
+            fieldvalue = {'iTotalRecords': len(fieldvalue),
+                          'iTotalDisplayRecords': len(fieldvalue),
+                          'aaData': fieldvalue }
 
         return json.dumps(fieldvalue)
 
@@ -318,7 +334,7 @@ class PlominoDocument(CatalogAware, CMFBTreeFolder, Contained):
         """
         db = self.getParentDatabase()
         db.deleteDocument(self)
-        if not REQUEST is None:
+        if REQUEST:
             return_url = REQUEST.get('returnurl')
             REQUEST.RESPONSE.redirect(return_url)
 
@@ -419,12 +435,9 @@ class PlominoDocument(CatalogAware, CMFBTreeFolder, Contained):
 
         # update the Plomino_Authors field with the current user name
         if asAuthor:
-            authors = self.getItem('Plomino_Authors')
+            authors = asList(self.getItem('Plomino_Authors') or [])
             name = db.getCurrentUser().getUserName()
-            if authors == '':
-                authors = []
-                authors.append(name)
-            elif name in authors:
+            if name in authors:
                 pass
             else:
                 authors.append(name)
@@ -652,7 +665,11 @@ class PlominoDocument(CatalogAware, CMFBTreeFolder, Contained):
         if not self.isReader():
             raise Unauthorized, "You cannot read this content"
 
-        onOpenDocument_error = self._onOpenDocument()
+        # Check access based on doc's current form. Plomino may be busy
+        # rendering a different doc, using some requested form, which 
+        # probably doesn't apply to this document.
+        form = self.getParentDatabase().getForm(self.Form)
+        onOpenDocument_error = self._onOpenDocument(form=form)
         if onOpenDocument_error:
             raise Unauthorized, onOpenDocument_error
 
@@ -773,7 +790,7 @@ class PlominoDocument(CatalogAware, CMFBTreeFolder, Contained):
         # if REQUEST exists, test the current command
         if hasattr(self, 'REQUEST'):
             command=self.REQUEST.URL.split('/')[-1].lower()
-            return command in ['editdocument', 'edit']
+            return command in ['editdocument', 'edit', 'savedocument']
         else:
             return False
 
@@ -866,16 +883,16 @@ class TemporaryDocument(PlominoDocument):
     security = ClassSecurityInfo()
 
     def __init__(self, parent, form, REQUEST, real_doc=None):
-        self._parent=parent
-        if real_doc is not None:
-            self.items=real_doc.items.copy()
-            self.real_id=real_doc.id
+        self._parent = parent
+        self.REQUEST = REQUEST
+        if real_doc:
+            self.items = real_doc.items.copy()
+            self.real_id = real_doc.id
         else:
-            self.items={}
-            self.real_id="TEMPDOC"
+            self.items = {}
+            self.real_id = "TEMPDOC"
         self.setItem('Form', form.getFormName())
         form.readInputs(self, REQUEST)
-        self._REQUEST=REQUEST
 
     security.declarePublic('getParentDatabase')
     def getParentDatabase(self):
@@ -893,17 +910,17 @@ class TemporaryDocument(PlominoDocument):
     def isNewDocument(self):
         """
         """
-        if self.real_id=="TEMPDOC":
+        if self.real_id == "TEMPDOC":
             return True
-        else:
-            return False
+        return False
 
-    security.declarePublic('REQUEST')
-    @property
-    def REQUEST(self):
+    security.declarePublic('isDocument')
+    def isDocument(self):
+        """ Return True if we're representing an existing document.
         """
-        """
-        return self._REQUEST
+        if self.id == 'TEMPDOC':
+            return False
+        return True
 
     security.declarePublic('id')
     @property
