@@ -32,7 +32,6 @@ from jsonutil import jsonutil as json
 from Products.CMFCore.utils import getToolByName
 
 from exceptions import PlominoScriptException
-import PlominoDocument
 from PlominoDocument import TemporaryDocument
 
 import logging
@@ -252,6 +251,17 @@ class PlominoForm(ATFolder):
 
     schema = PlominoForm_schema
 
+    def getForm(self, formname=None):
+        """ In case we're being called via acquisition.
+        """
+        if formname:
+            return self.getParentDatabase().getForm(self, formname)
+
+        form = self
+        while getattr(form, 'meta_type', '') != 'PlominoForm':
+            form = obj.aq_parent
+        return form
+
     security.declareProtected(CREATE_PERMISSION, 'createDocument')
     def createDocument(self,REQUEST):
         """create a document using the forms submitted content
@@ -303,10 +313,11 @@ class PlominoForm(ATFolder):
 
     security.declarePublic('getFormFields')
     def getFormFields(self, includesubforms=False, doc=None, applyhidewhen=False):
-        """get fields
+        """ Get fields
         """
-        fieldlist = self.objectValues(spec='PlominoField')
-        result = [f for f in fieldlist]
+        form = self.getForm()
+        fieldlist = form.objectValues(spec='PlominoField')
+        result = [f for f in fieldlist] # Convert from LazyMap to list
         if applyhidewhen:
             doc = doc or TemporaryDocument(self.getParentDatabase(), self, self.REQUEST)
             layout = self.applyHideWhen(doc)
@@ -449,7 +460,7 @@ class PlominoForm(ATFolder):
         parent_form = self.getParentDatabase().getForm(doc.Plomino_Parent_Form)
         parent_field = parent_form.getFormField(doc.Plomino_Parent_Field)
         fields = parent_field.getSettings().field_mapping.split(',')
-
+        
         raw_values = []
         for f in fields:
             v = doc.getItem(f)
@@ -651,7 +662,9 @@ class PlominoForm(ATFolder):
     def getFormField(self, fieldname, includesubforms=True):
         """return the field
         """
-        field = getattr(self, fieldname, None)
+        form = self.getForm()
+
+        field = getattr(form, fieldname, None)
         # if field is not in main form, we search in the subforms
         if not field:
             all_fields = self.getFormFields(includesubforms=includesubforms)
@@ -676,6 +689,7 @@ class PlominoForm(ATFolder):
             try:
                 fieldvalue = db.runFormulaScript("field_"+self.id+"_"+fieldname+"_formula", target, field.Formula, True, self)
             except PlominoScriptException, e:
+                logger.warning('%s field formula failed' % fieldname, exc_info=True)
                 if report:
                     e.reportError('%s field formula failed' % fieldname)
 
@@ -690,7 +704,9 @@ class PlominoForm(ATFolder):
 
     security.declarePrivate('_has_fieldtypes')
     def _has_fieldtypes(self, types):
-        "Tyeps is an array of strings. Check if any of those types is present"
+        """ ``types`` is an array of strings.
+        Check if any of those types are present.
+        """
         tmp = None
         if hasattr(self, 'REQUEST'):
             # hideWhens need a TemporaryDocument
@@ -958,14 +974,9 @@ class PlominoForm(ATFolder):
 
     security.declarePublic('isEditMode')
     def isEditMode(self):
+        """ When rendering a form without a document, it's always in edit mode.
         """
-        """
-        # if REQUEST exists, test the current command
-        if hasattr(self, 'REQUEST'):
-            command=self.REQUEST.URL.split('/')[-1].lower()
-            return command in ['openform', 'edit']
-        else:
-            return False
+        return True
 
     security.declarePublic('tojson')
     def tojson(self, REQUEST=None, item=None):
@@ -973,10 +984,14 @@ class PlominoForm(ATFolder):
         (Note: we use 'item' instead of 'field' to match the
         PlominoDocument.tojson method signature)
         """
+        datatables_format = False
         if REQUEST:
             REQUEST.RESPONSE.setHeader('content-type', 'application/json; charset=utf-8')
             item = REQUEST.get('item', item)
-
+            datatables_format_str = REQUEST.get('datatables', None)
+            if datatables_format_str:
+                datatables_format = True
+                
         result = None
         if not item:
             fields = self.getFormFields()
@@ -991,6 +1006,11 @@ class PlominoForm(ATFolder):
                 adapt = field.getSettings()
                 result = adapt.getFieldValue(self, None, False, False, REQUEST)
 
+        if datatables_format:
+            result = {'iTotalRecords': len(result),
+                      'iTotalDisplayRecords': len(result),
+                      'aaData': result }
+
         return json.dumps(result)
 
     def _getDatabaseViews(self):
